@@ -160,16 +160,21 @@ from . import adapter_wattpadcom
 from . import adapter_novelonlinefullcom
 from . import adapter_wwwnovelallcom
 from . import adapter_wuxiaworldco
+from . import adapter_novelupdatescc
 from . import adapter_harrypotterfanfictioncom
 from . import adapter_hentaifoundrycom
 from . import adapter_mugglenetfanfictioncom
 from . import adapter_swiorgru
 from . import adapter_fanficsme
-from . import adapter_archivehpfanfictalkcom
+from . import adapter_fanfictalkcom
 from . import adapter_scifistoriescom
 from . import adapter_silmarillionwritersguildorg
 from . import adapter_chireadscom
 from . import adapter_scribblehubcom
+from . import adapter_fictionlive
+from . import adapter_wuxiaworldsite
+from . import adapter_thesietchcom
+from . import adapter_fastnovelnet
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
