@@ -1,6 +1,6 @@
 #  -*- coding: utf-8 -*-
 
-# Copyright 2019 FanFicFare team
+# Copyright 2020 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,8 +36,7 @@ def getClass():
 
 
 class WuxiaWorldCoSiteAdapter(BaseSiteAdapter):
-    NEW_DATE_FORMAT = '%Y/%m/%d %H:%M:%S'
-    OLD_DATE_FORMAT = '%m/%d/%Y %I:%M:%S %p'
+    DATE_FORMAT = '%Y-%m-%d %H:%M'
 
     def __init__(self, config, url):
         BaseSiteAdapter.__init__(self, config, url)
@@ -80,57 +79,64 @@ class WuxiaWorldCoSiteAdapter(BaseSiteAdapter):
             raise exception
 
         soup = self.make_soup(data)
-        info = soup.select_one('#info')
-        self.story.setMetadata('title', stripHTML(info.h1))
-        self.setCoverImage(self.url, soup.select_one('#fmimg > img')['src'])
 
-        info_paragraphs = info('p')
-        # Unicode strings because '：' isn't ':', but \xef\xbc\x9a
-        author = stripHTML(info_paragraphs[0]).replace(u'Author：', '', 1)
+        self.setCoverImage(self.url, soup.select_one('.book-img > img')['src'])
+
+        book_info = soup.select_one('.book-info')
+        author = book_info.select_one('.author > .name').get_text()
+        self.story.setMetadata('title', book_info.select_one('.book-name').get_text())
         self.story.setMetadata('author', author)
         self.story.setMetadata('authorId', author)
-        datestr = stripHTML(info_paragraphs[2]).replace(u'UpdateTime：', '', 1)
-        date = None
-        try:
-            ## Some older stories use a different date format.
-            date = makeDate(datestr, self.NEW_DATE_FORMAT)
-        except ValueError:
-            date = makeDate(datestr, self.OLD_DATE_FORMAT)
+        ## site doesn't have authorUrl links.
+
+        chapter_info = soup.select_one('.chapter-wrapper')
+        date = makeDate(chapter_info.select_one('.update-time').get_text(), self.DATE_FORMAT)
         if date:
             self.story.setMetadata('dateUpdated', date)
 
-        intro = soup.select_one('#intro')
-        # Strip <strong>Description</strong>
+        intro = soup.select_one('.synopsis > .content')
         if intro.strong:
             intro.strong.decompose()
         self.setDescription(self.url, intro)
 
-        dl = soup.select_one('#list > dl')
-        for el in dl.contents:
-            if el.name == u'dt':
-                match = re.match(ensure_text(r'^《.+》\s+(.+)$'), stripHTML(el), re.UNICODE)
-                volume = ''
-                if match and match.group(1) != 'Text':
-                    volume = match.group(1) + ' '
-            elif el.name == u'dd':
-                a = el.a
-                if a['style'] != 'color:Gray;':
-                    # skip grayed out "In preparation" chapters
-                    url = urlparse.urljoin(self.url, a['href'])
-                    title = volume + stripHTML(a)
-                    self.add_chapter(title, url)
-            # else:
-            #     logger.debug('Unexpected tag in #list > dl: %s', el.name)
+        chapters = chapter_info.select('.chapter-item')
+        if self.getConfig("dedup_order_chapter_list",False):
+            # Sort and deduplicate chapters (some stories in incorrect order and/or duplicates)
+            chapters_data = []
+            numbers_regex = re.compile(r'[^0-9\.]') # Everything except decimal and numbers
+            for ch in chapters:
+                chapter_title = ch.p.get_text()
+                chapter_url = ch['href']
+                if chapter_title.startswith('Chapter'):
+                    target_number = chapter_title.split()[1]
+                else:
+                    target_number = chapter_title.split()[0]
+                try:
+                    number = float(re.sub(numbers_regex, '', target_number))
+                except:
+                    continue # Cannot parse chapter number
+                chapters_data.append((number, chapter_title, chapter_url))
+
+            chapters_data.sort(key=lambda ch: ch[0])
+
+            for index, chapter in enumerate(chapters_data):
+                if index > 0:
+                    # No previous duplicate chapter names or same chapter numbers
+                    if chapter[1] == chapters_data[index-1][1] or chapter[0] == chapters_data[index-1][0]:
+                        continue
+                title = chapter[1]
+                url = urlparse.urljoin(self.url, chapter[2])
+                self.add_chapter(title, url)
+        else:
+            ## normal operation
+            for ch in chapters:
+                self.add_chapter(ch.p.get_text(), urlparse.urljoin(self.url, ch['href']))
 
     def getChapterText(self, url):
         logger.debug('Getting chapter text from: %s', url)
         data = self._fetchUrl(url)
         soup = self.make_soup(data)
 
-        content = soup.select_one('#content')
-
-        # Script empty script tag at the end of the content
-        for script in content('script'):
-            script.decompose()
+        content = soup.select_one('.chapter-entity')
 
         return self.utf8FromSoup(url, content)
