@@ -40,7 +40,7 @@ else: # > 3.0
     def pickle_load(f):
         return pickle.load(f,encoding="bytes")
 
-version="3.22.1"
+version="3.25.0"
 os.environ['CURRENT_VERSION_ID']=version
 
 global_cache = 'global_cache'
@@ -75,7 +75,6 @@ except ImportError:
     from fanficfare.six.moves import http_cookiejar as cl
     from fanficfare.six import text_type as unicode
 
-
 def write_story(config, adapter, writeformat,
                 metaonly=False, nooutput=False,
                 outstream=None):
@@ -126,7 +125,7 @@ def main(argv=None,
                       help='Exclude list of chapters("zchapters") from metadata stdout output.  No effect without --meta-only or --json-meta flags', )
     parser.add_option('-j', '--json-meta',
                       action='store_true', dest='jsonmeta',
-                      help='Output metadata as JSON with download, or with --meta-only flag.  (Only JSON will be output with --meta-only flag.)', )
+                      help='Output metadata as JSON with download, or with --meta-only flag.  (Only JSON will be output with --meta-only flag.)  Also now series name and desc if available with --list', )
     parser.add_option('--no-output',
                       action='store_true', dest='nooutput',
                       help='Do not download chapters and do not write output file.  Intended for testing and with --meta-only.', )
@@ -190,9 +189,19 @@ def main(argv=None,
     parser.add_option('--save-cache', '--save_cache',
                       action='store_true', dest='save_cache',
                       help=SUPPRESS_HELP, )
+    ## 'undocumented' feature to allow expired/unverified SSL certs pass.
+    parser.add_option('--unverified_ssl',
+                      action='store_true', dest='unverified_ssl',
+                      help=SUPPRESS_HELP, )
 
     options, args = parser.parse_args(argv)
 
+    if options.unverified_ssl:
+        logger.warning("Running with unverified SSL context(--unverified_ssl), security may be compromised.")
+        import ssl
+        if hasattr(ssl, '_create_unverified_context'):
+            ssl._create_default_https_context = ssl._create_unverified_context
+
     if not options.debug:
         logger.setLevel(logging.WARNING)
     else:
@@ -240,25 +249,42 @@ def main(argv=None,
         parser.print_help();
         return
 
+    if options.save_cache:
+        try:
+            with open(global_cache,'rb') as jin:
+                options.pagecache = pickle_load(jin)
+            options.cookiejar = cl.LWPCookieJar()
+            options.cookiejar.load(global_cookies)
+        except Exception as e:
+            ## This is not uncommon, will happen when starting a new
+            ## cache, for example.
+            print("Didn't load --save-cache %s"%e)
+
     if options.list:
         configuration = get_configuration(options.list,
                                           passed_defaultsini,
                                           passed_personalini,options)
-        retlist = get_urls_from_page(options.list, configuration)
-        print('\n'.join(retlist))
+        frompage = get_urls_from_page(options.list, configuration)
+        if options.jsonmeta:
+            import json
+            print(json.dumps(frompage, sort_keys=True,
+                             indent=2, separators=(',', ':')))
+        else:
+            retlist = frompage.get('urllist',[])
+            print('\n'.join(retlist))
 
     if options.normalize:
         configuration = get_configuration(options.normalize,
                                           passed_defaultsini,
                                           passed_personalini,options)
-        retlist = get_urls_from_page(options.normalize, configuration,normalize=True)
+        retlist = get_urls_from_page(options.normalize, configuration,normalize=True).get('urllist',[])
         print('\n'.join(retlist))
 
     if options.downloadlist:
         configuration = get_configuration(options.downloadlist,
                                           passed_defaultsini,
                                           passed_personalini,options)
-        retlist = get_urls_from_page(options.downloadlist, configuration)
+        retlist = get_urls_from_page(options.downloadlist, configuration).get('urllist',[])
         urls.extend(retlist)
 
     if options.imaplist or options.downloadimap:
@@ -289,15 +315,6 @@ def main(argv=None,
                     #print("url: (%s)"%url)
                     urls.append(url)
 
-    if options.save_cache:
-        try:
-            with open(global_cache,'rb') as jin:
-                options.pagecache = pickle_load(jin)
-            options.cookiejar = cl.LWPCookieJar()
-            options.cookiejar.load(global_cookies)
-        except Exception as e:
-            print("Didn't load --save-cache %s"%e)
-
     if not list_only:
         if len(urls) < 1:
             print("No valid story URLs found")
@@ -314,12 +331,6 @@ def main(argv=None,
                         raise
                     print("URL(%s) Failed: Exception (%s). Run URL individually for more detail."%(url,e))
 
-    # Saved in configurable.py now.
-    # if options.save_cache:
-    #     with open('global_cache','wb') as jout:
-    #         pickle.dump(options.pagecache,jout,protocol=2)
-    #     options.cookiejar.save('global_cookies')
-
 # make rest a function and loop on it.
 def do_download(arg,
                 options,
@@ -365,19 +376,6 @@ def do_download(arg,
 
         adapter = adapters.getAdapter(configuration, url)
 
-        ## Share pagecache and cookiejar between multiple downloads.
-        if not hasattr(options,'pagecache'):
-            options.pagecache = configuration.get_empty_pagecache()
-        if not hasattr(options,'cookiejar'):
-            options.cookiejar = configuration.get_empty_cookiejar()
-        if options.save_cache:
-            save_cache = global_cache
-            save_cookies = global_cookies
-        else:
-            save_cache = save_cookies = None
-        configuration.set_pagecache(options.pagecache,save_cache)
-        configuration.set_cookiejar(options.cookiejar,save_cookies)
-
         # url[begin-end] overrides CLI option if present.
         if ch_begin or ch_end:
             adapter.setChaptersRange(ch_begin, ch_end)
@@ -612,6 +610,19 @@ def get_configuration(url,
     if options.progressbar:
         configuration.set('overrides','progressbar','true')
 
+    ## Share pagecache and cookiejar between multiple downloads.
+    if not hasattr(options,'pagecache'):
+        options.pagecache = configuration.get_empty_pagecache()
+    if not hasattr(options,'cookiejar'):
+        options.cookiejar = configuration.get_empty_cookiejar()
+    if options.save_cache:
+        save_cache = global_cache
+        save_cookies = global_cookies
+    else:
+        save_cache = save_cookies = None
+    configuration.set_pagecache(options.pagecache,save_cache)
+    configuration.set_cookiejar(options.cookiejar,save_cookies)
+
     return configuration
 
 if __name__ == '__main__':
