@@ -215,7 +215,7 @@ def get_valid_set_options():
                'fix_fimf_blockquotes':(['fimfiction.net'],None,boollist),
                'fail_on_password':(['fimfiction.net'],None,boollist),
                'keep_prequel_in_description':(['fimfiction.net'],None,boollist),
-               'include_author_notes':(['fimfiction.net'],None,boollist),
+               'include_author_notes':(['fimfiction.net','royalroad.com'],None,boollist),
                'do_update_hook':(['fimfiction.net',
                                   'archiveofourown.org'],None,boollist),
                'always_login':(['archiveofourown.org']+base_xenforo_list,None,boollist),
@@ -256,6 +256,7 @@ def get_valid_set_options():
                'include_images':(None,['epub','html'],boollist),
                'grayscale_images':(None,['epub','html'],boollist),
                'no_image_processing':(None,['epub','html'],boollist),
+               'dedup_img_files':(None,['epub','html'],boollist),
                'normalize_text_links':(None,['epub','html'],boollist),
                'internalize_text_links':(None,['epub','html'],boollist),
 
@@ -268,7 +269,7 @@ def get_valid_set_options():
                'use_reader_mode':(base_xenforo_list,None,boollist),
                'author_avatar_cover':(base_xenforo_list,None,boollist),
                'remove_spoilers':(base_xenforo_list+['royalroad.com'],None,boollist),
-               'legend_spoilers':(base_xenforo_list+['royalroad.com'],None,boollist),
+               'legend_spoilers':(base_xenforo_list+['royalroad.com', 'fiction.live'],None,boollist),
                'apocrypha_to_omake':(base_xenforo_list,None,boollist),
                'replace_failed_smilies_with_alt_text':(base_xenforo_list,None,boollist),
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
@@ -279,7 +280,11 @@ def get_valid_set_options():
                'use_threadmarks_cover':(base_xenforo2_list,None,boollist),
                'skip_sticky_first_posts':(base_xenforo2_list,None,boollist),
                'fix_pseudo_html': (['webnovel.com'], None, boollist),
-               'fix_excess_space': (['novelonlinefull.com', 'novelall.com'], ['epub', 'html'], boollist)
+               'fix_excess_space': (['novelonlinefull.com', 'novelall.com'], ['epub', 'html'], boollist),
+               'dedup_order_chapter_list': (['wuxiaworld.co', 'novelupdates.cc'], None, boollist),
+               'show_nsfw_cover_images': (['fiction.live'], None, boollist),
+               'show_timestamps': (['fiction.live'], None, boollist),
+               'show_nsfw_cover_images': (['fiction.live'], None, boollist)
                }
 
     return dict(valdict)
@@ -404,6 +409,7 @@ def get_valid_keywords():
                  'keep_html_attrs',
                  'replace_tags_with_spans',
                  'keep_empty_tags',
+                 'remove_tags',
                  'keep_summary_html',
                  'logpage_end',
                  'logpage_entries',
@@ -420,6 +426,7 @@ def get_valid_keywords():
                  'never_make_cover',
                  'cover_min_size',
                  'no_image_processing',
+                 'dedup_img_files',
                  'non_breaking_spaces',
                  'download_text_version',
                  'nook_img_fix',
@@ -499,8 +506,12 @@ def get_valid_keywords():
                  'datethreadmark_format',
                  'fix_pseudo_html',
                  'fix_excess_space',
+                 'dedup_order_chapter_list',
                  'ignore_chapter_url_list',
                  'dedup_chapter_list',
+                 'show_timestamps',
+                 'show_nsfw_cover_images',
+                 'show_spoiler_tags',
                  'max_zalgo',
                  'epub_version',
                  ])
