@@ -457,6 +457,7 @@ class Story(Configurable):
         self.chapter_last = None
         self.imgurls = []
         self.imgtuples = []
+        self.imgsizes = defaultdict(list) # dict of img sizes -> lists of self.imgtuples indices
         # save processed metadata, dicts keyed by 'key', then (removeentities,dorepl)
         # {'key':{(removeentities,dorepl):"value",(...):"value"},'key':... }
         self.processed_metadata_cache = {}
@@ -835,12 +836,15 @@ class Story(Configurable):
 
         self.extendList("extratags",self.getConfigList("extratags"))
 
-        if self.getMetadataRaw('seriesUrl'):
-            self.setMetadata('seriesHTML',linkhtml%('series',
-                                                    self.getMetadata('seriesUrl', removeallentities, doreplacements),
-                                                    self.getMetadata('series', removeallentities, doreplacements)))
-        elif self.getMetadataRaw('series'):
-            self.setMetadata('seriesHTML',self.getMetadataRaw('series'))
+        series = self.getMetadata('series', removeallentities, doreplacements)
+        seriesUrl = self.getMetadata('seriesUrl', removeallentities, doreplacements)
+        if series:
+            # linkhtml isn't configurable.  If it ever is, we may want
+            # to still set seriesHTML without series.
+            if seriesUrl:
+                self.setMetadata('seriesHTML',linkhtml%('series',seriesUrl,series))
+            else:
+                self.setMetadata('seriesHTML',series)
 
         # logger.debug("make_linkhtml_entries:%s"%self.getConfig('make_linkhtml_entries'))
         for k in self.getConfigList('make_linkhtml_entries'):
@@ -1283,6 +1287,7 @@ class Story(Configurable):
             if cover and cover_big_enough:
                 if len(self.imgtuples) > 0 and 'cover' in self.imgtuples[0]['newsrc']:
                     # remove existing cover, if there is one.
+                    # could have only come from first image and is assumed index 0.
                     del self.imgurls[0]
                     del self.imgtuples[0]
                 self.imgurls.insert(0,imgurl)
@@ -1290,7 +1295,20 @@ class Story(Configurable):
                 self.cover=newsrc
                 self.setMetadata('cover_image','specific')
                 self.imgtuples.insert(0,{'newsrc':newsrc,'mime':mime,'data':data})
+                ## *Don't* include cover in imgsizes because it can be
+                ## replaced by Calibre etc.  So don't re-use it.
+                ## Also saves removing it above.
+                # self.imgsizes[len(data)].append(0)
             else:
+                if self.getConfig('dedup_img_files',False):
+                    same_sz_imgs = self.imgsizes[len(data)]
+                    for szimg in same_sz_imgs:
+                        if data == self.imgtuples[szimg]['data']:
+                            # matching data, duplicate file with a different URL.
+                            logger.debug("found duplicate image: %s, %s"%(self.imgtuples[szimg]['newsrc'],
+                                                                          self.imgurls[szimg]))
+                            return (self.imgtuples[szimg]['newsrc'],
+                                    self.imgurls[szimg])
                 self.imgurls.append(imgurl)
                 # First image, copy not link because calibre will replace with it's cover.
                 # Only if: No cover already AND
@@ -1307,19 +1325,21 @@ class Story(Configurable):
                     self.setMetadata('cover_image','first')
                     self.imgtuples.append({'newsrc':newsrc,'mime':mime,'data':data})
                     self.imgurls.append(imgurl)
+                    ## *Don't* include cover in imgsizes because it can be
+                    ## replaced by Calibre etc.  So don't re-use it.
+                    # self.imgsizes[len(data)].append(len(self.imgtuples)-1)
 
                 newsrc = "images/%s-%s.%s"%(
                     prefix,
                     self.imgurls.index(imgurl),
                     ext)
                 self.imgtuples.append({'newsrc':newsrc,'mime':mime,'data':data})
+                self.imgsizes[len(data)].append(len(self.imgtuples)-1)
 
-            #logger.debug("\nimgurl:%s\nnewsrc:%s\nimage size:%d\n"%(imgurl,newsrc,len(data)))
+            # logger.debug("\n===============\nimgurl:%s\nnewsrc:%s\nimage size:%d %s\n============"%(imgurl,newsrc,len(data),self.imgsizes[len(data)]))
         else:
             newsrc = self.imgtuples[self.imgurls.index(imgurl)]['newsrc']
 
-        #print("===============\n%s\nimg url:%s\n============"%(newsrc,self.imgurls[-1]))
-
         return (newsrc, imgurl)
 
     def getImgUrls(self):
